// On side nav click
$('.PrefsSideNavItem').click(function () {
	// Get the clicked section code
	var newSection = $(this).attr('rel');

	// De-activate old nav and section
	$('.PrefsSideNavItem').removeClass('active');
	$('.PrefsSection').removeClass('active');

	// Activate new nav and section
	$('.PrefsSideNavItem[rel='+newSection+']').addClass('active');
	$('.PrefsSection[rel='+newSection+']').addClass('active');
});

// Show buttons on change of an input
$('.PrefsInput').on('keyup change', function (ev) {

	// Skip if already saving
	if ( isSaving ) {
		return;
	}

	// Get field name of the input
	var inputName = $(this).attr('name');

	// If enter key pressed then call save
	if ( 13 == ev.keyCode ) {
		savePref(inputName);
		return;
	}

	// If TAB key was pressed then skip
	if ( 9 == ev.keyCode ) {
		return;
	}

	// Hide other things
	$('.PrefsMsg[rel='+inputName+'_msg]').hide();
	$('.PrefsBtn[rel='+inputName+'_saving]').hide();

	// Show the buttons related to that input
	$('.PrefsBtn[rel='+inputName+']').show();
});

// Show save button on change of a payment preference input
$('.PPrefsInput').keydown(function (ev) {

	// Get field name of the input
	var code = $(this).attr('rel').replace('pm_', '');

	// If enter key pressed then call save
	if ( 13 == ev.keyCode ) {
		savePaymentPref(code);
		return;
	}

	// If TAB key was pressed then skip
	if ( 9 == ev.keyCode ) {
		return;
	}

	// Hide other things
	$('.PrefsMsg[rel=pm_'+code+'_msg]').hide();
	$('.PrefsBtn[rel=pm_'+code+'_saving]').hide();

	// Show the save button related to that input
	$('.PrefsBtn[rel=pm_'+code+']').show();
});

// Save preference value to db via ajax
var isSaving = false;
function savePref(name, value, indicator) {
	// If already saving then skip
	if ( isSaving ) {
		alert('Already saving a setting. Please refresh if stuck.');
		return;
	}

	// Mark that we are saving a setting
	isSaving = true;

	// Get input object
	$input = $('.PrefsInput[name='+name+']');

	// Check if it is not a field then quit with msg
	if ( typeof $input.get(0) ===  'undefined' ) {
		alert('There is some misconfiguration in the system');
		return;
	}

	// Load other params
	if ( typeof value === 'undefined' ) {
		value = $input.val();
	}
	if ( typeof indicator === 'undefined' ) {
		indicator = name;
	}

	// Show loading
	$('.PrefsBtn[rel='+name+']').hide();
	$('.PrefsBtn[rel='+indicator+'_saving]').show();

	postData = 'fld=' + encodeURIComponent(name) + '&';
	
	// If base64 field
	if ( $input.get(0).hasAttribute('data-b64') ) {
		postData += 'val=' + encodeURIComponent( encodeBase64( value ) ) + '&';
		postData += 'b64=1&';
	}
	
	// If checkbox field
	else if ( $input.is(':checkbox') && '' == value ) {
		postData += 'val=' + encodeURIComponent( $input.get(0).checked ? value : '' ) + '&';
	}

	// If text field
	else {
		postData += 'val=' + encodeURIComponent( value ) + '&';
	}

	// Call to save preference
	getContentFromUrl('preferences-submit-ajax.php', $('#divAjaxHiddenContent').get(0), 'POST', postData, 'savePrefReturn(\''+name+'\', \''+indicator+'\')');
}

// Save preference return action
function savePrefReturn(name, indicator) {
	// Get response from ajax
	response = $('#divAjaxHiddenContent').html();
	console.log(response);

	// Mark that we saving is done
	isSaving = false;

	// Load other params
	if ( typeof indicator === 'undefined' ) {
		indicator = name;
	}

	if ( 'OK' == response ) {
		// Show message
		$('.PrefsMsg[rel='+indicator+'_msg]').html('Preference saved').removeClass('PrefsMsgFail').addClass('PrefsMsgOk');
		$('.PrefsMsg[rel='+indicator+'_msg]').show();
		// Hide saving indicator
		$('.PrefsBtn[rel='+indicator+'_saving]').hide();
		// Set new data value for cancel event
		$('input.PrefsInput[name='+name+']').attr('data-value', $('.PrefsInput[name='+name+']').val());
	}

	else {
		// Show message
		$('.PrefsMsg[rel='+indicator+'_msg]').html(response).removeClass('PrefsMsgOk').addClass('PrefsMsgFail');
		$('.PrefsMsg[rel='+indicator+'_msg]').show();
		// Hide saving indicator
		$('.PrefsBtn[rel='+indicator+'_saving]').hide();
	}

	// Special case for template_theme
    if ( 'template_theme' == indicator ) {
        $('#idReloadThemeLogNotice').show();
    }

}

// Cancel preference editing
function cancelPref(name) {
	// Get the field object
	$field = $('input.PrefsInput[name='+name+']');

	// Restore the value (only for input fields)
	$field.val( $field.attr( 'data-value' ) );

	// Hide the buttons
	$('.PrefsBtn[rel='+name+']').hide();
}

// Change payment preference
function clickedPaymentPref(obj) {

	// Get the code
	var code = obj.name.replace('pm_', '');

	// Cleanup
	$('.PrefsMsg[rel=pm_'+code+'_msg]').hide();

	// if the option is checked then show sub options and save etc
	if ( obj.checked ) {
		$('.PrefsBtn[rel=pm_'+code+']').show();
		$('#id_pm_'+code+'_data').show();
	}

	// If the option is un-checked then save via ajax
	else {
		// Hide buttons
		$('.PrefsBtn[rel=pm_'+code+']').hide();
		$('#id_pm_'+code+'_data').hide();
		// Show saving
		$('.PrefsBtn[rel=pm_'+code+'_saving]').show();
		// Call to save preference
		getContentFromUrl('preferences-submit-ajax.php', $('#divAjaxHiddenContent').get(0), 'POST', 'fld=paymentPref&act=unset&typ='+code, 'savePrefReturn(\'pm_'+code+'\')');
	}

}

/**
 * Save payment preference
 * @param code
 */
function savePaymentPref(code) {
	// Make data to send
	var data = 'fld=paymentPref&act=save&typ='+code+'&';

	$('[rel=pm_'+code+']').each(function () {
		data += $(this).attr('name') + '=' + encodeURIComponent($(this).val()) + '&';
	});

	// Show saving
	$('.PrefsMsg[rel=pm_'+code+'_msg]').hide();
	$('.PrefsBtn[rel=pm_'+code+']').hide();
	$('.PrefsBtn[rel=pm_'+code+'_saving]').show();

	// Call to save preference
	getContentFromUrl('preferences-submit-ajax.php', $('#divAjaxHiddenContent').get(0), 'POST', data, 'savePrefReturn(\'pm_'+code+'\')');
}


// Special functions / events - START

function useModRewrite_beforeUpdate(obj) {
	// If seo urls were disabled then save and quit
	if ( obj.value == 'N' ) {
		savePref('constant-USE_MOD_REWRITE', 'N');
		return;
	}

	// Else ask to re-generate urls and only then allow to save the preferences

	// Reset the radio button value
	$('#id_constant-USE_MOD_REWRITE_N').attr('checked', 'checked');

	// Show pop so that user can re-build seo urls
	showPop('<h2>Enable SEO Urls</h2><br>'+
				'To enable seo urls, you must run the job to re-build SEO urls.<br><br>'+
				'This step is necessary for the SEO urls to work correctly.<br><br>'+
				'<div style="text-align:center">'+
				'<button class="btn btn-success" onclick="useModRewrite_rebuildUrls()">Re-build SEO Urls</button> &nbsp; '+
				'<button class="btn btn-danger" onclick="hidePop();">Cancel</button>'+
				'</div>',
			550, 200, '', 12, '#555555', false);
}

function useModRewrite_rebuildUrls() {
	window.open('_tools/setup-search-friendly-urls.php?btnConfirm=+Yes+');
	$('#id_constant-USE_MOD_REWRITE_Y').attr('checked', 'checked');
	savePref('constant-USE_MOD_REWRITE', 'Y');
	hidePop();
}

// Special functions / events - END


// Base 64 encode function and its helpers
var END_OF_INPUT = -1;
var base64Chars = [
	'A','B','C','D','E','F','G','H','I','J','K','L','M','N','O','P','Q','R','S','T','U','V','W','X','Y','Z','a','b','c','d','e','f',
	'g','h','i','j','k','l','m','n','o','p','q','r','s','t','u','v','w','x','y','z','0','1','2','3','4','5','6','7','8','9','+','/'
];
var base64Str;
var base64Count;
function setBase64Str(str){
	base64Str = str;
	base64Count = 0;
}
function readBase64(){    
	if (!base64Str) return END_OF_INPUT;
	if (base64Count >= base64Str.length) return END_OF_INPUT;
	var c = base64Str.charCodeAt(base64Count) & 0xff;
	base64Count++;
	return c;
}
function encodeBase64(str){
	setBase64Str(str);
	var result = '';
	var inBuffer = new Array(3);
	var lineCount = 0;
	var done = false;
	while (!done && (inBuffer[0] = readBase64()) != END_OF_INPUT){
		inBuffer[1] = readBase64();
		inBuffer[2] = readBase64();
		result += (base64Chars[ inBuffer[0] >> 2 ]);
		if (inBuffer[1] != END_OF_INPUT){
			result += (base64Chars [(( inBuffer[0] << 4 ) & 0x30) | (inBuffer[1] >> 4) ]);
			if (inBuffer[2] != END_OF_INPUT){
				result += (base64Chars [((inBuffer[1] << 2) & 0x3c) | (inBuffer[2] >> 6) ]);
				result += (base64Chars [inBuffer[2] & 0x3F]);
			} else {
				result += (base64Chars [((inBuffer[1] << 2) & 0x3c)]);
				result += ('=');
				done = true;
			}
		} else {
			result += (base64Chars [(( inBuffer[0] << 4 ) & 0x30)]);
			result += ('=');
			result += ('=');
			done = true;
		}
		lineCount += 4;
		if (lineCount >= 76){
			result += ('\n');
			lineCount = 0;
		}
	}
	return result;
}
