<?php
//*************************************************************************************************
//		Price Comparison Script copyright Kaon Softwares ( http://www.kaonsoftwares.com )
//=================================================================================================
//		NOTICE: Do NOT remove the copyright and/or license information from this file.
//				doing so will automatically terminate your rights to use this program.
//-------------------------------------------------------------------------------------------------
//		This file comes with the license agreement. You must abide by the agreement. Any violation
//		will automatically result in termination of your rights to use this program.
//		See license agreement at www.kaonsoftwares.com/license.html
//-------------------------------------------------------------------------------------------------
//		You may modify the source code but this copyright notice MUST remain on all
//		PriceComparison Script's files.
//*************************************************************************************************
//		INCLUDES
//*************************************************************************************************

//*************************************************************************************************
//		OVERRIDE NORMAL DEFINES
//*************************************************************************************************

// Donot use smart images loading as it will not be available in the target where api data is used
define('USE_SMART_IMAGES_LOADING', 0);

//*************************************************************************************************
//		INCLUDES
//*************************************************************************************************

require("path.php");
require(PATH . "include/include.php");

//*************************************************************************************************
//		CONSTANTS & VARIABLES
//*************************************************************************************************

define('DATA_API_VERSION', '1.0');

$currencySymbol = SCRIPT_DOLLAR;
$currencyRate = 1;

//*************************************************************************************************
//		INPUTS HANDLING
//*************************************************************************************************

// Type of data to be returned: xml or json, default is json.
$dataApiType = $_GET['type'];
$dataApiType = in_array($dataApiType, ['json', 'xml']) ? $dataApiType : 'json';

// Publisher Id
$dataApiID = getVar('id', 'int');

// Publisher Key
$dataApiKey = getVar('key');

// Api method to call:
//	ver:		get data-api version
//	catslist:	get list of categories
$dataApiAct = $_GET['act'];

//*************************************************************************************************
//		INPUTS TESTING
//*************************************************************************************************

if ($dataApiID < 1)
    dataApiError('Publisher ID is missing');

if ($dataApiKey == '')
    dataApiError('Publisher API Key is missing');

if (!($rec = getRecord('DATA_API_PUBLISHER', $dataApiID)))
    dataApiError('Publisher does not exist');

if ($rec['API_KEY'] != $dataApiKey)
    dataApiError('Publisher API Key is not valid');

//*************************************************************************************************
//		ACTION: Version
//*************************************************************************************************

if ($dataApiAct == 'ver')
    dataApiOutput(['Version' => DATA_API_VERSION]);

//*************************************************************************************************
//		ACTION: Category List
//*************************************************************************************************

if ($dataApiAct == 'catslist') {
    $cats = ['Categories' => []];

    $cids = trimUniqueCsvVals(getVar('cids'));    // get clean comma separated category ids
    $pids = trimUniqueCsvVals(getVar('pids'));    // get clean comma separated parent ids

    $ssql = '';

    if ($cids != '')
        $ssql .= 'AND ID IN (' . $cids . ')';

    if ($pids != '')
        $ssql .= 'AND PARENT_ID IN (' . $pids . ')';

    $res = executeQuery("SELECT ID, PARENT_ID AS ParentID, TITLE AS CatName FROM " . PREFIX . "CATEGORY WHERE ISVALID='Y' " . $ssql . " ORDER BY LEVEL, TITLE");
    while (($row = getRow($res)))
        $cats['Categories'][] = $row;

    dataApiOutput($cats);
}

//*************************************************************************************************
//		ACTION: Category Tree
//*************************************************************************************************

if ($dataApiAct == 'catstree') {
    $cats = ['Categories' => []];

    dataApiRecursiveCats($cats['Categories']);

    dataApiOutput($cats);
}

//*************************************************************************************************
//		ACTION: Brands list
//*************************************************************************************************

if ( $dataApiAct == 'brands' ) {
	$brands = [ 'Brands' => [] ];

	$feat = getVar( 'feat', 'int' );
	$max  = getVar( 'max', 'int' );
	$max  = $max < 0 ? 12 : $max;

	$res = executeQuery(
		"SELECT ID, TITLE AS BrandName, FILENAME AS SEOName FROM " . PREFIX . "BRAND ".
		"WHERE ISVALID='Y' ".(1 == $feat ? "AND SHOW_ON_HOMEPAGE='Y'" : "")." ORDER BY TITLE LIMIT ".$max );
	while ( ( $row = getRow( $res ) ) ) {
		$row['ImageUrl'] = '';

		$imgPath = 'upload/brand/' . $row['ID'] . '.jpg';
		if ( file_exists( PATH_SUBD . $imgPath ) ) {
			$row['ImageUrl'] = getReadFileLink( $imgPath );
		}

		$brands['Brands'][] = $row;
	}

	dataApiOutput( $brands );
}

//*************************************************************************************************
//		ACTION: Stores list
//*************************************************************************************************

if ($dataApiAct == 'stores') {
    $stores = ['Stores' => []];

    $res = executeQuery("SELECT U.USERID AS ID, UI.NAME AS StoreName, UI.ADDRESS AS Address, UI.CITY AS City, UI.STATE AS State, UI.COUNTRY AS Country, UI.PHONE AS StoreContactNo, UI.EMAIL AS EmailAddress, U.REGISTERATION_DATE AS WithUsSince, UI.URL AS StoreUrl FROM " . PREFIX . "USER U, " . PREFIX . "USERINFO UI WHERE U.ISVALID='Y' AND UI.USERID=U.USERID ORDER BY UI.NAME");
    while (($row = getRow($res))) {
        $imgPath = 'upload/merchant/' . $row['ID'] . '.jpg';

        if (file_exists(PATH_SUBD . $imgPath))
            $row['ImageUrl'] = getReadFileLink($imgPath);

        $stores['Stores'][] = $row;
    }

    dataApiOutput($stores);
}

//*************************************************************************************************
//		ACTION: Products list
//*************************************************************************************************

if ($dataApiAct == 'products') {
    $cid = getVar('cid', 'int');
    $kwd = getVar('kwd', defined('USES_CYRILIC_CHARS') && USES_CYRILIC_CHARS == 1 ? '' : 'a-zA-Z0-9 \/\.:+-');
    $sortk = getVar('sortk');
    $sortm = strtolower(getVar('sortm')) == 'desc' ? 'desc' : 'asc';
    $pgno = getVar('pgno', 'int');
    $max = getVar('max', 'int');

    if (!in_array($sortk, ['ProdName', 'MinPrice', 'StoreCount'])) {
        $sortk = 'StoreCount desc, ProdName';
        $sortm = '';
    }

    $pgno = $pgno < 1 ? 1 : $pgno;
    $pgno = $pgno > 100 ? 100 : $pgno;

    $max = $max < 5 ? 5 : $max;
    $max = $max > 100 ? 100 : $max;

    $cids = SHOW_PRODUCTS_ON_MID_LEVEL_CATEGORIES == 1 ? getChildCategoryList($cid) : getLastLevelChildList($cid);

    if (count($cids) == 0 && $kwd == '')
        dataApiError('Insufficient parameters, must provide either a valid category id or a search keyword');

    $prods = ['Products' => []];

    $subsql = '';
    if (count($cids) > 0) {
        $subsql .= 'CATEGORY_ID IN (' . implode(',', $cids) . ') AND ';
    }
    if ($kwd != '') {
        $subsql .= getSearchColumnByWord('TITLE', $kwd) . ' AND ';
    }

    $cats = [];
    $arr = [];
    $res = executeQuery("SELECT ID, TITLE AS ProdName, CATEGORY_ID AS CatID, '' AS CatName, FILENAME AS SEOName, MIN_PRICE AS MinPrice, STORE_COUNT AS StoreCount FROM " . PREFIX . "PRODUCT WHERE " . $subsql . " ISVALID='Y' ORDER BY " . $sortk . " " . $sortm . " LIMIT " . (($pgno - 1) * $max) . "," . $max);
    while (($row = getRow($res))) {
        $cats[] = $row['CatID'];
        $arr[] = $row;
    }

    $cats = array_unique($cats);
    $crecs = [];
    if (count($cats) > 0) {
        $res = executeQuery("SELECT ID, PARENT_ID, TITLE, FILENAME FROM " . PREFIX . "CATEGORY WHERE ID IN (" . implode(',', $cats) . ")");
        while (($row = getRow($res)))
            $crecs[ $row['ID'] ] = $row;
    }

    foreach ($arr as $row) {
        $row['ImageUrl'] = getProductThumbUrl($row['ID'], 500, 500, $row['SEOName'], ' ');

        if (isset($crecs[ $row['CatID'] ]))
            $row['CatName'] = $crecs[ $row['CatID'] ]['TITLE'];

        $row['PCSLink'] = str_replace('&amp;', '&', getProductPath($row['ID'], $row['SEOName'], $row['CatID'], isset($crecs[ $row['CatID'] ]) ? $crecs[ $row['CatID'] ]['FILENAME'] : ''));

        $row['MinPrice'] = getFormattedPrice($row['MinPrice'], SCRIPT_DOLLAR, 1);

        $prods['Products'][] = $row;
    }

    dataApiOutput($prods);
}

//*************************************************************************************************
//		ACTION: Product Info
//*************************************************************************************************

if ($dataApiAct == 'product') {
    $pid = getVar('prod', 'int');

    if ($pid == 0)
        dataApiError('Please provide product id to get its info');

    if (!($prec = getRecord('PRODUCT', $pid)))
        dataApiError('Product with id=' . $pid . ' does not exist');

    if ($prec['ISVALID'] != 'Y')
        dataApiError('Product is not active');

    $prec['IMAGE_URL'] = getProductThumbUrl($prec['ID'], 800, 800, $prec['FILENAME'], ' ');

    $prec['MIN_PRICE'] = getFormattedPrice($prec['MIN_PRICE'], SCRIPT_DOLLAR, 1);
    $prec['MAX_PRICE'] = getFormattedPrice($prec['MAX_PRICE'], SCRIPT_DOLLAR, 1);

    $prec['Offers'] = [];

    $sql = "SELECT UP.ID, UP.USERID, UP.PRICE, UP.SHIPPING, UP.ISAVAILABLE, UP.COMMENT, UP.BUY_URL, U.ISFEATURED, U.IS_TRUSTED, UI.NAME, UI.FILENAME " .
        "FROM " . PREFIX . "USER U, " . PREFIX . "USERINFO UI, " . PREFIX . "USER_PRODUCT UP " .
        "WHERE U.USERID = UP.USERID AND U.USERID = UI.USERID AND UP.PRODUCT_ID = " . $pid . " AND U.ISVALID = 'Y' " .
        "AND U.PAYMENTDUE = 'N' AND UP.ISVALID='Y' " .
        "ORDER BY  " . (IS_MERCHANTBID_INSTALLED != 0 ? 'BID_AMOUNT DESC,' : '') . " U.ISFEATURED, PRICE " .
        "LIMIT 50";

    $res = executeQuery($sql);
    while (($row = getRow($res))) {

        $row['REDIRECT_URL'] = getSeoUrl('redirect', 'prod_id=' . $row['ID'] . '&amp;isBuy=Y');

        if (file_exists(PATH_SUBD . "upload/merchant/" . $row["USERID"] . ".jpg"))
            $row['LOGO_IMAGE'] = getMerchantLogoThumbUrl($row['USERID'], 120, 50, $row['NAME']);
        else
            $row['LOGO_IMAGE'] = '';

        $shiptax = 0;
        if (DO_SHOW_SHIPPING_FROM_DB == 1) {
            $shiptax = str_replace(SCRIPT_DOLLAR, '', $row['SHIPPING']);

            if (IS_COMMA_DECIMAL_SEPARATOR == 1)
                $shiptax = str_replace(',', '.', $row['SHIPPING']);
        }

        $row['TAXAMT'] = 0;

        $row['SHIPTAX'] = $shiptax;
        $row['TOTAL'] = ((!is_numeric($shiptax) ? $row['TAXAMT'] : $row['SHIPTAX'] + $row['TAXAMT']) + $row["PRICE"]);

        $row['FORMATTED_TOTAL'] = getFormattedPrice($row['TOTAL'], $currencySymbol, $currencyRate);
        $row['FORMATTED_TAXAMT'] = getFormattedPrice($row['TAXAMT'], $currencySymbol, $currencyRate);
        $row['FORMATTED_PRICE'] = getFormattedPrice($row['PRICE'], $currencySymbol, $currencyRate);

        $prec['Offers'][] = (object)$row;
    }

    $prod = [
        'Product' => $prec,
    ];

    dataApiOutput($prod);
}

//*************************************************************************************************
//		ACTION: Not specified or not handled
//*************************************************************************************************

dataApiError('No action specified');

//*************************************************************************************************
//		FUNCTIONS
//*************************************************************************************************

function dataApiOutput($inarr)
{
    global $dataApiType;

    $data = [];
    $data['TimeStamp'] = time();
    $data['IPAddress'] = getClientIP();

    if (!is_array($inarr))
        $inarr = ['Error' => $inarr];

    $data['Message'] = $inarr;

    if ($dataApiType == 'xml') {
        header('Content-Type: application/xml; charset=utf-8');
        $oXml = new SimpleXMLElement('<' . '?xml version="1.0" encoding="UTF-8"?><KaonPCSEnvelope></KaonPCSEnvelope>');
        dataApiArray2Xml($data, $oXml);
        echo $oXml->asXML();
    }
    else {
        header('Content-Type: application/json; charset=utf-8');
        echo json_encode($data);
    }
    die;
}

//*************************************************************************************************

function dataApiArray2Xml($data, &$oXml, $pnode = '')
{
    if ($pnode != '') {
        if (substr($pnode, -3) == 'ies')
            $pnode = substr($pnode, 0, -3) . 'y';
        elseif (substr($pnode, -1) == 's')
            $pnode = substr($pnode, 0, -1);
    }

    foreach ($data as $key => $value) {
        if (is_array($value)) {
            if (is_numeric($key)) {
                if ($pnode == '')
                    $key = 'child';
                else
                    $key = $pnode;
            }
            $subnode = $oXml->addChild($key);
            dataApiArray2Xml($value, $subnode, is_numeric($key) ? $pnode : $key);
        }
        else
            $oXml->addChild($key, htmlspecialchars($value));
    }
}

//*************************************************************************************************

function dataApiError($message)
{
    dataApiOutput($message);
}

//*************************************************************************************************

function dataApiRecursiveCats(&$arr, $pid = 0)
{
    $res = executeQuery("SELECT ID, TITLE AS CatName FROM " . PREFIX . "CATEGORY WHERE PARENT_ID=" . $pid . " AND ISVALID='Y' ORDER BY TITLE");
    while (($row = getRow($res))) {
        $childs = [];
        dataApiRecursiveCats($childs, $row['ID']);
        if (count($childs) > 0)
            $row['Categories'] = $childs;

        $arr[] = $row;
    }
}


//*************************************************************************************************
?>