/**
 * Names of the caches used in this version of the service worker.
 * Change to v2, etc. when you update any of the local resources, which will
 * in turn trigger the install event again.
 * @type {string}
 */
const PRECACHE = 'precache-v3';

/**
 * A list of local resources we always want to be cached.
 * @type {string[]}
 */
const PRECACHE_URLS = [
// enabling this below line causes the main page to be cached by service worker and then the them updates dont work
//    './',
    'style/public.min.css',
    'js/main.js'
];

/**
 * The install handler takes care of precaching the resources we always need.
 */
self.addEventListener('install', function(event) {
    event.waitUntil(
        caches.open(PRECACHE)
            .then(function(cache) {
                console.log('Opened cache');
                return cache.addAll(PRECACHE_URLS);
            })
    );
});

/**
 * The activate handler takes care of cleaning up old caches.
 */
self.addEventListener('activate', function(event) {

    var cacheWhitelist = [PRECACHE];

    event.waitUntil(
        caches.keys().then(function(cacheNames) {
            return Promise.all(
                cacheNames.map(function(cacheName) {
                    if (cacheWhitelist.indexOf(cacheName) === -1) {
                        return caches.delete(cacheName);
                    }
                })
            );
        })
    );
});

/**
 * The fetch handler serves responses for same-origin resources from a cache.
 */
self.addEventListener('fetch', function(event) {
    event.respondWith(
        caches.match(event.request)
            .then(function(response) {
                    if (response) {
						console.log('Cache Hit!');
                        return response;
                    }
                    return fetch(event.request);
                }
            )
    );
});
